/*
 *  GUI/Tools.cs
 *  Copyright (C) 2006-2007 Marcin Krystian Krzywonos
 *  License: GNU/GPL version 2
 */


using System;
using System.Reflection;
using System.Diagnostics;
using Gdk;
using Gtk;
using Glade;
using System.IO;
using Mono.Unix;
using Microsoft.Win32;


namespace Incollector.GUI {
	
	/*
	 * Colors class
	 */
	
	public static class Tools {
		
		/// <summary>Repaints application.</summary>
		static public void Repaint ()
		{
			while (Application.EventsPending ())
				Application.RunIteration ();
		}
		
		private static string GetDefaultWinBrowserPath()
		{
            string path1 = @"Software\Clients\StartMenuInternet";
			RegistryKey key1 = Registry.CurrentUser.OpenSubKey(path1, false);
            string browser = (string)key1.GetValue(null, null);
            
            string path2 = @"Software\Clients\StartMenuInternet\" + browser + @"\shell\open\command";
            RegistryKey key2 = Registry.LocalMachine.OpenSubKey(path2, false);
            string full_path = (string)key2.GetValue(null, null);

            if (full_path != "") {
                return full_path;
            } else {
                return "iexplore.exe";
            }
		}
		
		/// <summary>Runs web browser with specified URL.</summary>
		public static void RunWebBrowser (string Url)
		{
			if (Engine.FilesPaths.IsWinSystem () == true) {
				try {
					Process.Start(GetDefaultWinBrowserPath(), Url);
				} catch {
                    Process.Start("iexplore.exe", Url);
				}
			} else {
				if (TryRun (Engine.Settings.Get ("webbrowser"), Url) == false) {
					if (TryRun ("gnome-open", Url))
						return;
				
					if (TryRun ("firefox", Url))
						return;
				
					if (TryRun ("epiphany", "-t Url"))
						return;
				
					if (TryRun ("mozilla", Url))
						return;
				
					if (TryRun ("opera", Url))
						return;
				
					if (TryRun ("koqueror", Url))
						return;
				}
			}
		}
		
		
		public static bool TryRun (string command, string parameters)
		{
			try {
				System.Diagnostics.Process.Start (command, parameters);
				return true;
			} catch {
				return false;
			}
		}
		
		
		public static string CheckCommand (string command, string parameter)
		{
			foreach (string path in System.Environment.GetEnvironmentVariable ("PATH").Split (':')) {
				if (File.Exists (path + "/" + command))
					return command + " " + parameter;
			}
			
			return "";
		}
	}
}
