/*
 *  GUI/Widgets/SearchEntry.cs
 *  Copyright (C) 2006-2007 Marcin Krystian Krzywonos
 *  License: GNU/GPL version 2
 */


using System;
using Gtk;
using Mono.Unix;


namespace Incollector.GUI.Widgets {
	
	public class SearchEntry : Gtk.HBox {
		
		public string Query {
			get { return this.EntryWidget.Text; }
		}
		
		public bool Searching {
			get { return this.EntryWidget.Text.Length > 0; }
		}
		
		
		public Gtk.Widget FocusWidget {
			get { return this.EntryWidget; }
		}

		
		public delegate void FindActivateHandler (string Query);
		public event FindActivateHandler FindActivated;
		public delegate void EscapeHandler ();
		public event EscapeHandler Escaped;
		
		
		protected Gtk.Entry EntryWidget;
		protected Gdk.Color EntryColor;
		protected Gtk.Label label;
		protected int       CurrChar = -1;
		
		
		public SearchEntry (Gtk.Window ParentWindow) : base (false, 6)
		{
			label = new Gtk.Label (Catalog.GetString ("Search:"));
			this.PackStart (label, false, false, 0);
			
			Gtk.AccelGroup accel = new Gtk.AccelGroup ();
			ParentWindow.AddAccelGroup (accel);
			
			this.EntryWidget = new Gtk.Entry ();
			this.EntryWidget.AddAccelerator ("grab_focus", accel, 
				(uint) Gdk.Key.F, Gdk.ModifierType.ControlMask, Gtk.AccelFlags.Visible);
			this.EntryWidget.Changed += new EventHandler (OnChanged);
			this.EntryWidget.KeyReleaseEvent += new Gtk.KeyReleaseEventHandler (OnKeyReleased);
			this.PackStart (EntryWidget, true, true, 0);
			
			this.EntryColor = EntryWidget.Style.Base (Gtk.StateType.Normal);
			
			this.ShowAll ();
		}
		
		
		protected DateTime LastKey = DateTime.Today; 
		protected void OnChanged (object o, EventArgs args)
		{
			if (this.Searching)
				this.EntryWidget.ModifyBase (Gtk.StateType.Normal, this.Style.Backgrounds[1]);
			else
				this.EntryWidget.ModifyBase (Gtk.StateType.Normal, this.Style.BaseColors[0]);
			
			if ((DateTime.Now - LastKey).Seconds >= 1)
				GLib.Timeout.Add (1000, Check);
			LastKey = DateTime.Now;
		}
		
		protected bool Check ()
		{
			if (this.ParentWindow == null)
				return false;

			if ((DateTime.Now - LastKey).Seconds >= 1) {
				if (this.Query == "")
					this.EntryWidget.ModifyBase (Gtk.StateType.Normal, this.EntryColor);
				
				this.FindActivated (this.Query);
				return false;
			}
			
			return true;
		}
		
		
		protected void OnKeyReleased (object o, KeyReleaseEventArgs args)
		{
			if (args.Event.Key == Gdk.Key.Escape)
				this.Escape ();
		}
		
		
		public void SetEntryColor (Gdk.Color color)
		{
			this.EntryColor = color;
			this.EntryWidget.ModifyBase (Gtk.StateType.Normal, this.EntryColor);
			this.EntryWidget.ModifyBg (Gtk.StateType.Normal, this.EntryColor);
		}
		
		
		public void ResetEntryColor (Gdk.Color color)
		{
			this.EntryWidget.ModifyBg (Gtk.StateType.Normal);
			this.EntryColor = EntryWidget.Style.Base (Gtk.StateType.Normal);
		}
		
		
		public void SetLabelColor (Gdk.Color color)
		{
			this.label.ModifyFg (Gtk.StateType.Normal, color);
		}
		
		
		public void ResetLabelColor (Gdk.Color color)
		{
			this.label.ModifyFg (Gtk.StateType.Normal);
		}
		
		
		public void Escape ()
		{
			if ((this.EntryWidget.Text.Length == 0) && (this.Escaped != null))
				this.Escaped ();
			else
				this.EntryWidget.Text = "";
		}
	}
}
